@@ -1,7 +1,8 @@
 package PDF::WebKit::Configuration;
 use strict;
 use warnings;
-use Moose;
+use Moo;
+use namespace::clean;
 
 has meta_tag_prefix => ( is => 'rw' );
 has default_options => ( is => 'rw' );
@@ -36,9 +37,6 @@ sub _find_wkhtmltopdf {
   }
 }
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
-
 my $_config;
 sub configuration {
   $_config ||= PDF::WebKit::Configuration->new;
